@@ -12,5 +12,5 @@ KUYRUK_MANAGER_HOST = 'localhost'
 KUYRUK_MANAGER_PORT = 16501
 KUYRUK_MANAGER_HTTP_PORT = 16500
 KUYRUK_WORKERS = {
-    'aslan.local': 'a, c'
+    # 'aslan.local': 'a, c'
 }
