@@ -2,6 +2,8 @@ import json
 import pickle
 import logging
 
+from .helpers.json_datetime import JSONEncoder, JSONDecoder
+
 logger = logging.getLogger(__name__)
 
 
@@ -11,6 +13,7 @@ class Message(object):
         """
         :param message: return value of pika.Channel.basic_get
         :param queue: kuyruk.queue.Queue instance
+
         """
         self.queue = queue
         self.method = message[0]
@@ -30,6 +33,10 @@ class Message(object):
         """Decode and return wrapped message body."""
         return self.decode((self.method, self.properties, self.body))[1]
 
+    @staticmethod
+    def encode(obj):
+        return json.dumps(obj, cls=JSONEncoder)
+
     @staticmethod
     def decode(message):
         method, properties, body = message
@@ -37,7 +44,7 @@ class Message(object):
             return None, None
 
         if properties.content_type == 'application/json':
-            obj = json.loads(body)
+            obj = json.loads(body, cls=JSONDecoder)
         elif properties.content_type == 'application/python-pickle':
             obj = pickle.loads(body)
         else:
