@@ -3,16 +3,11 @@ import logging
 
 from kuyruk.channel import LazyChannel
 from kuyruk.queue import Queue
-from kuyruk.optionparser import OptionParser
 
 logger = logging.getLogger(__name__)
 
 
-def main():
-    parser = OptionParser()
-    parser.parse_args()
-    config = parser.config
-
+def run(config, args):
     channel = LazyChannel.from_config(config)
     channel.tx_select()
     failed_queue = Queue('kuyruk_failed', channel)
@@ -31,6 +26,3 @@ def main():
         channel.tx_commit()
 
     logger.info('All failed task are requeued.')
-
-if __name__ == '__main__':
-    main()
